"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaStreamService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const core_2 = require("@sourceloop/core");
const kafkajs_1 = require("kafkajs");
const keys_1 = require("./keys");
let KafkaStreamService = class KafkaStreamService {
    constructor(settings, adapter, logger, kafkaContructor) {
        this.settings = settings;
        this.adapter = adapter;
        this.logger = logger;
        this.kafkaContructor = kafkaContructor;
        if (!this.kafkaContructor) {
            this.kafkaContructor = kafkajs_1.Kafka;
        }
    }
    async subscribe(handler) {
        this.client = new this.kafkaContructor(this.settings.connection);
        this.consumer = this.client.consumer(this.settings.consumer);
        await this.consumer.connect();
        await this.consumer.subscribe({
            topics: this.settings.topics,
        });
        await this.consumer.run({
            eachMessage: async (payload) => {
                await this.adapter
                    .adaptTo(payload)
                    .then(message => handler(message).catch(err => this.logger.error(err)));
            },
        });
        this.consumer.on('consumer.connect', event => {
            this.logger.debug(`${event.payload}`);
        });
        this.consumer.on('consumer.crash', event => {
            this.logger.debug(`${event.payload}`);
        });
        this.consumer.on('consumer.disconnect', event => {
            this.logger.debug(`${event.payload}`);
        });
    }
    async unsubscribe() {
        var _a;
        await ((_a = this.consumer) === null || _a === void 0 ? void 0 : _a.disconnect());
    }
    async publish(event) {
        const config = this.settings.output;
        if (!config) {
            this.logger.error('No output config found for kafka connector');
            return;
        }
        if (!this.client) {
            this.client = new this.kafkaContructor(this.settings.connection);
        }
        const producer = this.client.producer(this.settings.producer);
        await producer.connect();
        const adapted = await this.adapter.adaptFrom(event);
        await producer.send({
            topic: config.topic,
            compression: kafkajs_1.CompressionTypes.GZIP,
            messages: [
                {
                    key: this.buildKey(config.key, adapted),
                    value: JSON.stringify(adapted),
                },
            ],
        });
        await producer.disconnect();
    }
    buildKey(key, event) {
        if (!key) {
            return '';
        }
        if (typeof key === 'string') {
            return key;
        }
        return key(event);
    }
};
exports.KafkaStreamService = KafkaStreamService;
exports.KafkaStreamService = KafkaStreamService = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(keys_1.TaskServiceKafkaModule.CONFIG)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.TaskServiceKafkaModule.ADAPTER)),
    tslib_1.__param(2, (0, core_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(3, (0, core_1.inject)(keys_1.TaskServiceKafkaModule.KAFKA_CLIENT, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Object, Object])
], KafkaStreamService);
//# sourceMappingURL=kafka-stream.service.js.map