"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const bpmn_service_1 = require("@sourceloop/bpmn-service");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const baseUrl = '/events';
let EventController = class EventController {
    constructor(eventWorkflowMapping, eventRepository, workflowRepository) {
        this.eventWorkflowMapping = eventWorkflowMapping;
        this.eventRepository = eventRepository;
        this.workflowRepository = workflowRepository;
    }
    async find(filter) {
        return this.eventRepository.find(filter);
    }
    async findById(id, filter) {
        return this.eventRepository.findById(id, filter);
    }
    async count(where) {
        return this.eventRepository.count(where);
    }
    async mapEventToWorkflow(eventWorkflowMapping) {
        await this.eventWorkflowMapping.create(eventWorkflowMapping);
    }
};
exports.EventController = EventController;
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16002" /* TaskPermssionKey.ViewEvent */],
    }),
    (0, rest_1.get)(baseUrl, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Array of Event model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.Event, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.filter(models_1.Event)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], EventController.prototype, "find", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16002" /* TaskPermssionKey.ViewEvent */],
    }),
    (0, rest_1.get)(`${baseUrl}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Event model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.Event, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.filter(models_1.Event, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], EventController.prototype, "findById", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: ["16002" /* TaskPermssionKey.ViewEvent */],
    }),
    (0, rest_1.get)(`${baseUrl}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Event model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.Event)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], EventController.prototype, "count", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)(`${baseUrl}/mapping`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {},
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.EventWorkflow, {
                    title: 'EventWorkflowMapping',
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], EventController.prototype, "mapEventToWorkflow", null);
exports.EventController = EventController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.EventWorkflowRepository)),
    tslib_1.__param(1, (0, repository_1.repository)(repositories_1.EventRepository)),
    tslib_1.__param(2, (0, repository_1.repository)(bpmn_service_1.WorkflowRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.EventWorkflowRepository,
        repositories_1.EventRepository,
        bpmn_service_1.WorkflowRepository])
], EventController);
//# sourceMappingURL=event.controller.js.map